Attribute VB_Name = "Lmpqapi"
Option Explicit

'  Lmpqapi declarations for VB converted by ShadowFlare

'  Lelik 's MPQ API Library. (c) Andrey lelikov, Moscow 1999.
  
'  All functions below are actually located in storm.dll or staredit.exe.
'  This library loads staredit.exe in "server" mode, and interacts as
'  "client", providing a gateway to call mpq-related functions.

'  Revision History:
'  2000/11 2.00 (quantam@campaigncreations.com)
'  + 1 year anniversary blowout, including:
'  - New coauthor (hi!)
'  - Renamed Storm-based functions to "SFile" prefix to avoid confusion
'  - Added MpqAddWAVToArchive, MpqRenameFile, MpqCompactArchive,
'    SFileGetFileInfo, and MpqGetVersion functions
'  - Figured out all but 2 of the unknown parameters in all functions combined
'  - Added full error-handling capabilities through GetLastError()
'  - Improved reliability a bit
'  - LMPQAPI now requires StarEdit.exe from either Starcraft or Brood War 1.07.
'    No other versions will work
'  - Working on a comprehensive user's manual right now

'  2000/01 1.04 (alelikov@mtu-net.ru)
'  - Added function MpqDeleteFile

'  2000/01 1.03 (alelikov@mtu-net.ru)
'  - Discovered last parameter in MpqOpenArchiveForUpdate

'  1999/12 1.02 (alelikov@mtu-net.ru)
'  - Added constants for MOAU_MAINTAIN_LISTFILE & MAFA_REPLACE_EXISTING flags.

'  1999/11 1.00 (alelikov@mtu-net.ru)
'  - First version.

'  This library is freeware, you can do anything you want with it but with
'  one exception. If you use it in your program, you must specify this fact
'  in Help|About box or in similar way. You can obtain version string using
'  MpqGetVersionString call.

'  THIS LIBRARY IS DISTRIBUTED "AS IS".  NO WARRANTY OF ANY KIND IS EXPRESSED
'  OR IMPLIED. YOU USE AT YOUR OWN RISK. THE AUTHOR WILL NOT BE LIABLE FOR
'  DATA LOSS, DAMAGES, LOSS OF PROFITS OR ANY OTHER KIND OF LOSS WHILE USING
'  OR MISUSING THIS SOFTWARE.

'  Any comments or suggestions are accepted at ALelikov@mtu-net.ru (Lelik) or omega@dragonfire.net (Quantam)

Declare Function MpqInitialize Lib "lmpqapi.dll" () As Boolean
Declare Function MpqGetVersionString Lib "lmpqapi.dll" () As String
Declare Function MpqGetVersion Lib "lmpqapi.dll" () As Single

'General error codes
Public Const MPQ_ERROR_INIT_FAILED = &H85000001 'Unspecified error
Public Const MPQ_ERROR_NO_STAREDIT = &H85000002 'Can't find StarEdit.exe
Public Const MPQ_ERROR_BAD_STAREDIT = &H85000003 'Bad version of StarEdit.exe. Need SC/BW 1.07
Public Const MPQ_ERROR_STAREDIT_RUNNING = &H85000004 'StarEdit.exe is running. Must be closed

Public Const MPQ_ERROR_MPQ_INVALID = &H85200065
Public Const MPQ_ERROR_FILE_NOT_FOUND = &H85200066
Public Const MPQ_ERROR_DISK_FULL = &H85200068 'Physical write file to MPQ failed. Not sure of exact meaning
Public Const MPQ_ERROR_HASH_TABLE_FULL = &H85200069
Public Const MPQ_ERROR_ALREADY_EXISTS = &H8520006A
Public Const MPQ_ERROR_BAD_OPEN_MODE = &H8520006C 'When MOAU_READ_ONLY is used without MOAU_OPEN_EXISTING

Public Const MPQ_ERROR_COMPACT_ERROR = &H85300001

'MpqOpenArchiveForUpdate flags
Public Const MOAU_CREATE_NEW = &H0
Public Const MOAU_CREATE_ALWAYS = &H8 'Was wrongly named MOAU_CREATE_NEW
Public Const MOAU_OPEN_EXISTING = &H4
Public Const MOAU_OPEN_ALWAYS = &H20
Public Const MOAU_READ_ONLY = &H10 'Must be used with MOAU_OPEN_EXISTING
Public Const MOAU_MAINTAIN_LISTFILE = &H1

' AddFileToArchive flags
Public Const MAFA_EXISTS = &H80000000 'Will be added if not present
Public Const MAFA_UNKNOWN40000000 = &H40000000
Public Const MAFA_MODCRYPTKEY = &H20000
Public Const MAFA_ENCRYPT = &H10000
Public Const MAFA_COMPRESS = &H200
Public Const MAFA_COMPRESS2 = &H100
Public Const MAFA_REPLACE_EXISTING = &H1

' AddWAVToArchive flags
Public Const MAWA_QUALITY_HIGH = 1
Public Const MAWA_QUALITY_MEDIUM = 0
Public Const MAWA_QUALITY_LOW = 2

' SFileGetFileInfo flags
Public Const SFILE_INFO_BLOCK_SIZE = &H1 'Block size in MPQ
Public Const SFILE_INFO_HASH_TABLE_SIZE = &H2 'Hash table size in MPQ
Public Const SFILE_INFO_NUM_FILES = &H3 'Number of files in MPQ
Public Const SFILE_INFO_TYPE = &H4 'Is Long a file or an MPQ?
Public Const SFILE_INFO_SIZE = &H5 'Size of MPQ or uncompressed file
Public Const SFILE_INFO_COMPRESSED_SIZE = &H6 'Size of compressed file
Public Const SFILE_INFO_FLAGS = &H7 'File flags (compressed, etc.)
Public Const SFILE_INFO_PARENT = &H8 'Handle of MPQ that file is in
Public Const SFILE_INFO_POSITION = &H9 'Position of file pointer in files

Public Const SFILE_TYPE_MPQ = &H1
Public Const SFILE_TYPE_FILE = &H2

Public Const INVALID_HANDLE_VALUE As Long = -1

Public Const FILE_BEGIN   As Long = 0
Public Const FILE_CURRENT As Long = 1
Public Const FILE_END     As Long = 2

Public Const SFILE_OPEN_HARD_DISK_FILE As Long = &H0 'Open archive without regard to the drive type it resides on
Public Const SFILE_OPEN_CD_ROM_FILE As Long = &H1 'Open the archive only if it is on a CD-ROM

Public Const SFILE_SEARCH_CURRENT_ONLY As Long = &H0 'Used with SFileOpenFileEx; only the archive with the handle specified will be searched for the file
Public Const SFILE_SEARCH_ALL_OPEN As Long = &H1 'SFileOpenFileEx will look through all open archives for the file

' Staredit Function Prototypes
Declare Function MpqOpenArchiveForUpdate Lib "lmpqapi.dll" (ByVal lpFileName As String, ByVal dwFlags As Long, ByVal dwMaximumFilesInArchive As Long) As Long
Declare Function MpqCloseUpdatedArchive Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal dwUnknown2 As Long) As Long
Declare Function MpqAddFileToArchive Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal lpSourceFileName As String, ByVal lpDestFileName As String, ByVal dwFlags As Long) As Boolean
Declare Function MpqAddWaveToArchive Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal lpSourceFileName As String, ByVal lpDestFileName As String, ByVal dwFlags As Long, ByVal dwQuality As Long) As Boolean
Declare Function MpqRenameFile Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal lpcOldFileName As String, ByVal lpcNewFileName As String) As Boolean
Declare Function MpqDeleteFile Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal lpFileName As String) As Boolean
Declare Function MpqCompactArchive Lib "lmpqapi.dll" (ByVal hMPQ As Long) As Boolean

' Storm Function Prototypes
Declare Function SFileOpenArchive Lib "lmpqapi.dll" (ByVal lpFileName As String, ByVal dwPriority As Long, ByVal dwFlags As Long, ByRef hMPQ As Long) As Boolean
Declare Function SFileCloseArchive Lib "lmpqapi.dll" (ByVal hMPQ As Long) As Boolean
Declare Function SFileOpenFileEx Lib "lmpqapi.dll" (ByVal hMPQ As Long, ByVal lpFileName As String, ByVal dwSearchScope As Long, ByRef hFile As Long) As Boolean
Declare Function SFileCloseFile Lib "lmpqapi.dll" (ByVal hFile As Long) As Boolean
Declare Function SFileGetFileSize Lib "lmpqapi.dll" (ByVal hFile As Long, ByRef lpFileSizeHigh As Long) As Long
Declare Function SFileGetFileInfo Lib "lmpqapi.dll" (ByVal hFile As Long, ByVal dwInfoType As Long) As Long
Declare Function SFileSetFilePointer Lib "lmpqapi.dll" (ByVal hFile As Long, ByVal lDistanceToMove As Long, lplDistanceToMoveHigh As Long, ByVal dwMoveMethod As Long) As Long
Declare Function SFileReadFile Lib "lmpqapi.dll" (ByVal hFile As Long, lpBuffer As Byte, ByVal nNumberOfBytesToRead As Long, lpNumberOfBytesRead As Long, lpOverlapped As Any) As Boolean
Declare Function SFileSetLocale Lib "lmpqapi.dll" (ByVal nNewLocale As Long) As Long

